@@ -1,13 +1,16 @@
 import pytest
 
 
-@pytest.mark.bashcomp(skipif="! makepkg --help 2>&1 | grep -qiF slackware")
+@pytest.mark.bashcomp(
+    ignore_env=r"^-declare -f _makepkg_bootstrap$",
+    xfail="! makepkg --help 2>&1 | command grep -qiF slackware",
+)
 class TestMakepkg:
     @pytest.mark.complete("makepkg ")
     def test_1(self, completion):
         assert completion
 
-    @pytest.mark.complete("makepkg --")
+    @pytest.mark.complete("makepkg --", require_cmd=True)
     def test_2(self, completion):
         assert all(
             x in completion for x in "--chown --linkadd --prepend".split()
