@@ -6,6 +6,6 @@ class TestPasswd:
     def test_1(self, completion):
         assert completion
 
-    @pytest.mark.complete("passwd -")
+    @pytest.mark.complete("passwd -", require_cmd=True)
     def test_2(self, completion):
         assert completion
