@@ -3,7 +3,7 @@ import pytest
 
 class TestVgdisplay:
     @pytest.mark.complete(
-        "vgdisplay -", skipif="! vgdisplay --help &>/dev/null"
+        "vgdisplay -", require_cmd=True, xfail="! vgdisplay --help &>/dev/null"
     )
     def test_1(self, completion):
         assert completion
